@@ -9,40 +9,37 @@
 
 """Versioning tests for Invenio-DB"""
 
+from unittest.mock import patch
+
 import pytest
-from mock import patch
-from sqlalchemy_continuum import VersioningManager, make_versioned, \
-    remove_versioning
+from sqlalchemy_continuum import VersioningManager, remove_versioning
 from test_db import _mock_entry_points
 
 from invenio_db import InvenioDB
 
 
-@patch('importlib_metadata.entry_points',
-       _mock_entry_points('invenio_db.models_a'))
+@patch("importlib_metadata.entry_points", _mock_entry_points("invenio_db.models_a"))
 def test_disabled_versioning(db, app):
     """Test SQLAlchemy-Continuum with disabled versioning."""
-    InvenioDB(app, entry_point_group='invenio_db.models_a')
+    InvenioDB(app, entry_point_group="invenio_db.models_a")
 
     with app.app_context():
         assert 2 == len(db.metadata.tables)
 
 
-@pytest.mark.parametrize("versioning,tables", [
-    (False, 1),  (True, 3)
-])
+@pytest.mark.parametrize("versioning,tables", [(False, 1), (True, 3)])
 def test_disabled_versioning_with_custom_table(db, app, versioning, tables):
     """Test SQLAlchemy-Continuum table loading."""
-    app.config['DB_VERSIONING'] = versioning
+    app.config["DB_VERSIONING"] = versioning
 
     class EarlyClass(db.Model):
-
         __versioned__ = {}
 
         pk = db.Column(db.Integer, primary_key=True)
 
-    idb = InvenioDB(app, entry_point_group=None, db=db,
-                    versioning_manager=VersioningManager())
+    idb = InvenioDB(
+        app, entry_point_group=None, db=db, versioning_manager=VersioningManager()
+    )
 
     with app.app_context():
         db.drop_all()
@@ -62,14 +59,17 @@ def test_disabled_versioning_with_custom_table(db, app, versioning, tables):
         remove_versioning(manager=idb.versioning_manager)
 
 
-@patch('importlib_metadata.entry_points',
-       _mock_entry_points('invenio_db.models_b'))
+@patch("importlib_metadata.entry_points", _mock_entry_points("invenio_db.models_b"))
 def test_versioning(db, app):
     """Test SQLAlchemy-Continuum enabled versioning."""
-    app.config['DB_VERSIONING'] = True
+    app.config["DB_VERSIONING"] = True
 
-    idb = InvenioDB(app, entry_point_group='invenio_db.models_b', db=db,
-                    versioning_manager=VersioningManager())
+    idb = InvenioDB(
+        app,
+        entry_point_group="invenio_db.models_b",
+        db=db,
+        versioning_manager=VersioningManager(),
+    )
 
     with app.app_context():
         assert 4 == len(db.metadata.tables)
@@ -77,7 +77,8 @@ def test_versioning(db, app):
         db.create_all()
 
         from demo.versioned_b import UnversionedArticle, VersionedArticle
-        original_name = 'original_name'
+
+        original_name = "original_name"
 
         versioned = VersionedArticle()
         unversioned = UnversionedArticle()
@@ -91,7 +92,7 @@ def test_versioning(db, app):
 
         assert unversioned.name == versioned.name
 
-        modified_name = 'modified_name'
+        modified_name = "modified_name"
 
         versioned.name = modified_name
         unversioned.name = modified_name
@@ -120,12 +121,13 @@ def test_versioning(db, app):
 
 def test_versioning_without_versioned_tables(db, app):
     """Test SQLAlchemy-Continuum without versioned tables."""
-    app.config['DB_VERSIONING'] = True
+    app.config["DB_VERSIONING"] = True
 
-    idb = InvenioDB(app, db=db, entry_point_group=None,
-                    versioning_manager=VersioningManager())
+    idb = InvenioDB(
+        app, db=db, entry_point_group=None, versioning_manager=VersioningManager()
+    )
 
     with app.app_context():
-        assert 'transaction' in db.metadata.tables
+        assert "transaction" in db.metadata.tables
 
     remove_versioning(manager=idb.versioning_manager)
